==> chrome-extension-0.32.0.tgz: package/src/app/components/common/GlobalContext.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import * as React from "react";
import { EditorEnvelopeLocator } from "@kie-tools-core/editor/dist/api";
import { Logger } from "../../../Logger";
import { ExternalEditorManager } from "../../../ExternalEditorManager";
import { ResourceContentServiceFactory } from "./ChromeResourceContentService";
import { Dependencies } from "../../Dependencies";

export interface GlobalContextType {
  id: string;
  githubAuthTokenCookieName: string;
  envelopeLocator: EditorEnvelopeLocator;
  logger: Logger;
  dependencies: Dependencies;
  extensionIconUrl: string;
  resourceContentServiceFactory: ResourceContentServiceFactory;
  externalEditorManager?: ExternalEditorManager;
}

export const GlobalContext = React.createContext<GlobalContextType>({} as any);

export function useGlobals() {
  return React.useContext(GlobalContext);
}

==> chrome-extension-10.0.0.tgz: package/src/app/components/common/GlobalContext.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import * as React from "react";
import { EditorEnvelopeLocator, KogitoEditorChannelApi } from "@kie-tools-core/editor/dist/api";
import { Logger } from "../../../Logger";
import { ExternalEditorManager } from "../../../ExternalEditorManager";
import { ResourceContentServiceFactory } from "./ChromeResourceContentService";
import { Dependencies } from "../../Dependencies";
import { StateControl } from "@kie-tools-core/editor/dist/channel";

export interface GlobalContextType {
  id: string;
  githubAuthTokenCookieName: string;
  envelopeLocator: EditorEnvelopeLocator;
  logger: Logger;
  dependencies: Dependencies;
  extensionIconUrl: string;
  resourceContentServiceFactory: ResourceContentServiceFactory;
  externalEditorManager?: ExternalEditorManager;
  stateControl?: StateControl;
  customChannelApiImpl?: KogitoEditorChannelApi;
}

export const GlobalContext = React.createContext<GlobalContextType>({} as any);

export function useGlobals() {
  return React.useContext(GlobalContext);
}
